relistats package
=================

Submodules
----------

The submodules are as follows.

relistats.binomial module
-------------------------

.. automodule:: relistats.binomial
   :members:
   :undoc-members:
   :show-inheritance:

relistats.binom_fin module
--------------------------

.. automodule:: relistats.binom_fin
   :members:
   :undoc-members:
   :show-inheritance:

relistats.intervals module
--------------------------

.. automodule:: relistats.intervals
   :members:
   :undoc-members:
   :show-inheritance:

relistats.percentile module
---------------------------

.. automodule:: relistats.percentile
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: relistats
   :members:
   :undoc-members:
   :show-inheritance:
